@@ -598,8 +598,9 @@ void tfbm_open(TFrameBufferMemory* p)
 	p->cap = sFBCapabilityList[tvisual];
 
 #ifdef JFB_VGA16FB
+	/* see fbdpsp.c: ifdef JFB_VGA16FB */
 	if (fb_fix.type == FB_TYPE_VGA_PLANES) {
-		if ( ioperm(0x3c0, 0x20, 1 ) == -1 ) {
+		if ( util_privilege_ioperm(0x3c0, 0x20, 1 ) == -1 ) {
 			die("Cannot access VGA registers(ioperm).");
 		}
 	}
