@@ -29,6 +29,7 @@
 #include <stdlib.h>
 #include <sys/types.h>
 #include <string.h>
+#include <unistd.h>
 
 #include "config.h"
 
@@ -145,6 +146,11 @@ TFont gFont[] = {
 	FMACRO_96__FONT(0x48, FH_RIGHT, "iso8859.8-1988"),
 	FMACRO_96__FONT(0x4d, FH_RIGHT, "iso8859.9-1989"),
 	FMACRO_96__FONT(0x56, FH_RIGHT, "iso8859.10-1992"),
+	FMACRO_96__FONT(0x54, FH_RIGHT, "iso8859.11-2001"),
+	FMACRO_96__FONT(0x59, FH_RIGHT, "iso8859.13-1998"),
+	FMACRO_96__FONT(0x5f, FH_RIGHT, "iso8859.14-1998"),
+	FMACRO_96__FONT(0x62, FH_RIGHT, "iso8859.15-1999"),
+	FMACRO_96__FONT(0x66, FH_RIGHT, "iso8859.16-2001"),
 	/* CCITT T.101 Mosaic Charactor Sets */
 	FMACRO_94__FONT(0x79, FH_LEFT , "ccitt-mosaic-1"),
 	FMACRO_96__FONT(0x7d, FH_LEFT , "ccitt-mosaic-sup1"),
@@ -250,6 +256,31 @@ TFont gFont[] = {
 		FH_RIGHT, TFONT_ALIAS, NULL, sgFontsDefaultGlyph, NULL,
 		0xFF, 0x00, 0xFF, 0x00, 0x00, 1, 1
 	},
+	{ tfont_default_glyph,	"ISO8859-11", 1, 1,
+		TFONT_FT_SINGLE|TFONT_FT_96CHAR| 0x54,
+		FH_RIGHT, TFONT_ALIAS, NULL, sgFontsDefaultGlyph, NULL,
+		0xFF, 0x00, 0xFF, 0x00, 0x00, 1, 1
+	},
+	{ tfont_default_glyph,	"ISO8859-13", 1, 1,
+		TFONT_FT_SINGLE|TFONT_FT_96CHAR| 0x59,
+		FH_RIGHT, TFONT_ALIAS, NULL, sgFontsDefaultGlyph, NULL,
+		0xFF, 0x00, 0xFF, 0x00, 0x00, 1, 1
+	},
+	{ tfont_default_glyph,	"ISO8859-14", 1, 1,
+		TFONT_FT_SINGLE|TFONT_FT_96CHAR| 0x5f,
+		FH_RIGHT, TFONT_ALIAS, NULL, sgFontsDefaultGlyph, NULL,
+		0xFF, 0x00, 0xFF, 0x00, 0x00, 1, 1
+	},
+	{ tfont_default_glyph,	"ISO8859-15", 1, 1,
+		TFONT_FT_SINGLE|TFONT_FT_96CHAR| 0x62,
+		FH_RIGHT, TFONT_ALIAS, NULL, sgFontsDefaultGlyph, NULL,
+		0xFF, 0x00, 0xFF, 0x00, 0x00, 1, 1
+	},
+	{ tfont_default_glyph,	"ISO8859-16", 1, 1,
+		TFONT_FT_SINGLE|TFONT_FT_96CHAR| 0x66,
+		FH_RIGHT, TFONT_ALIAS, NULL, sgFontsDefaultGlyph, NULL,
+		0xFF, 0x00, 0xFF, 0x00, 0x00, 1, 1
+	},
 	{ tfont_default_glyph,	"JISX0212", 2, 1,
 		TFONT_FT_DOUBLE | TFONT_FT_94CHAR | 0x44,
 		FH_LEFT, TFONT_ALIAS, NULL, sgFontsDefaultDGlyph, NULL,
@@ -399,6 +430,10 @@ static void tfont_setup_font(TFont* pf, const char* fname, FONTSET_HALF hf)
 
 	tpcf_init(&pcf);
 
+	if (access(fname, R_OK) != 0) {
+		printf("PCF : CANNOTOPEN : %s\n", fname);
+		return;
+	}
 	if ((nf > 3 && strcmp(".gz", fname+nf-3) == 0) ||
 	    (nf > 2 && strcmp(".Z", fname+nf-2) == 0)) {
 		if (strlen(JFB_GZIP_PATH) + 10 + nf >= sizeof cmd) {
