@@ -42,7 +42,8 @@
 #include <fcntl.h>
 #include <sys/stat.h>
 #include <getopt.h>
-
+#include <locale.h>
+#include <langinfo.h>
 
 #include "pcf.h"
 #include "font.h"
@@ -69,6 +70,9 @@ static void tapp_get_options(TApplication* p, int argc, char *argv[])
 	static struct option optList[] = {
 		{"shell",	1, NULL, 'e'},
 		{"exec",	1, NULL, 'e'},
+		{"config",	1, NULL, 'f'},
+		{"encoding",	1, NULL, 'c'},
+		{"charmap",	1, NULL, 'c'},
 		{"help",	0, NULL, 'h'},
 		{NULL,		0, NULL, 0},
 	};
@@ -77,7 +81,7 @@ static void tapp_get_options(TApplication* p, int argc, char *argv[])
 	int i;
 	
 	while (1) {
-		c = getopt_long(argc, argv, "e:h", optList, &ix);
+		c = getopt_long(argc, argv, "e:hf:c:", optList, &ix);
 		if (c == EOF) {
 			break;
 		}
@@ -85,6 +89,12 @@ static void tapp_get_options(TApplication* p, int argc, char *argv[])
 		case 'e':
 			p->gExecShell = optarg;
 			break;
+		case 'f':
+			p->gConfFile = optarg;
+			break;
+		case 'c':
+			p->gConfEncoding = optarg;
+			break;
 		case 'h':
 			p->gOptShowHelpQ = TRUE;
 			break;
@@ -116,7 +126,7 @@ void tapp_change_to_original_console(TApplication* p)
                 print_strerror("/dev/console");
         }
         if (ioctl(cfd, VT_ACTIVATE, n) != 0) {
-                fprintf(stderr, "can't activate VC(%d)", n);
+                print_warn("can't activate VC(%d)", n);
         }
         close(cfd);
 }
@@ -157,6 +167,8 @@ void tapp_init(TApplication* p)
 		p->gExecShell = "/bin/sh";
 	}
 	p->gExecShellArgv = NULL;
+	p->gConfFile = FILE_JFBTERM_CONF;
+	p->gConfEncoding = NULL;
 
 	atexit(tapp_final_at_exit);
 }
@@ -197,7 +209,7 @@ void tapp_change_to_new_console(TApplication* p)
                 print_strerror_and_exit("fork");
         }
         if (child) {
-                fprintf(stderr, "\r\nJFBTERM> switched to new VC\r\n");
+                print_message("\r\nJFBTERM> switched to new VC\r\n");
 		p->gOrigVirtualConsoleQ	= FALSE;
                 exit(EXIT_SUCCESS);
         }
@@ -295,6 +307,50 @@ void ShowCaps(void)
 
 }
 
+const char *
+tapp_setup_encoding(const char *en)
+{
+	
+	if (strcmp(en, "locale") == 0) {
+		setlocale(LC_ALL, "");
+		en = nl_langinfo(CODESET);
+	}
+	if (strchr(en, ',') == NULL) {
+		TCapability* enctable;
+		TCapValue *ev;
+		const char *encname = en;
+		int elen = strlen(encname);
+
+		/* if quoted, remove it */
+		if ((encname[0] == '"' && encname[elen-1] == '"') 
+		    || (encname[0] == '\'' && encname[elen-1] == '\'')) {
+			encname = encname + 1;
+			elen -= 2;
+		}
+
+		en = NULL;
+		enctable = tcaps_find(&(gApp.gCaps), "enctable");
+		if (!enctable || !(enctable->values)) {
+			print_error("no encoding table found.\n");
+			exit(EXIT_FAILURE);
+		}
+		for (ev = enctable->values; ev ; ev = ev->next) {
+			if (strncasecmp(ev->value, encname, elen) == 0
+			    && ev->value[elen] == ',') {
+				/* found */
+				en = &ev->value[elen + 1];
+				break;
+			}
+		}
+		if (!en)
+			print_error("encoding[%s] not found, fallback to default\n", encname);
+	}
+	if (!en) {
+		en = "G0,G1,ansix3.4-1968,ansix3.4-1968,iso8859.1-1987,ansix3.4-1968";
+	}
+	return en;
+}
+
 int main(int argc, char *argv[])
 {
 	TCapability* fcap;
@@ -304,7 +360,7 @@ int main(int argc, char *argv[])
 
 	util_privilege_init();
 
-	fprintf(stderr,
+	print_message(
 		"%s - Kanji on framebuffer console Version %s\n"
 		"       Copyright (C) 2003 Fumitoshi UKAI\n"
 		"	Copyright (C) 1999-2000 Noritoshi Masuichi\n"
@@ -322,10 +378,10 @@ int main(int argc, char *argv[])
 		exit(EXIT_SUCCESS);
 	}
 
-	tcaps_read(&(gApp.gCaps), FILE_JFBTERM_CONF);
+	tcaps_read(&(gApp.gCaps), gApp.gConfFile);
 	fcap = tcaps_find(&(gApp.gCaps), "fontset"); 
 	if (!fcap || !(fcap->values)) {
-		fprintf(stderr, "no font specified.\n");
+		print_error("no font specified.\n");
 		exit(EXIT_FAILURE);
 	}
 
@@ -346,9 +402,19 @@ int main(int argc, char *argv[])
 		tn = "jfbterm";
 	}
 	en = tcaps_find_first(&(gApp.gCaps), "encoding");
-	if (!en) {
-		en = "G0,G1,ASCII,ISO8859-1,ASCII,ASCII";
+	if (gApp.gConfEncoding) {
+		en = gApp.gConfEncoding;
 	}
+	en = tapp_setup_encoding(en);
+
+	print_message("encoding : %s\n", en);
+	print_message("exec : %s ", gApp.gExecShell);
+	{
+		int i;
+		for (i = 1; gApp.gExecShellArgv[i]; i++)
+			print_message("%s ", gApp.gExecShellArgv[i]);
+	}
+
 	tterm_start(&gTerm, tn, en);
 
 	tfbm_close(&gFramebuffer);
