@@ -30,8 +30,8 @@
 
 #include <termios.h>
 
-#include <vterm.h>
-#include <mytypes.h>
+#include "vterm.h"
+#include "mytypes.h"
 
 #define SUCCESS       (0)
 
