@@ -28,6 +28,9 @@
 #include <string.h>
 #include <unistd.h>
 #include <sys/types.h>
+#include <sys/stat.h>
+#include <sys/io.h>
+#include <fcntl.h>
 
 #include "util.h"
 
@@ -65,6 +68,16 @@ util_privilege_open(char *pathname, int flags)
     return fd;
 }
 
+int
+util_privilege_ioperm(unsigned long from, unsigned int num, int turn_on)
+{
+    int r;
+    setreuid(runner_uid, owner_uid);
+    r = ioperm(from, num, turn_on);
+    setreuid(owner_uid, runner_uid);
+    return r;
+}
+
 uid_t
 util_getuid()
 {
