@@ -51,8 +51,8 @@
 static void tvterm_set_default_encoding(TVterm* p, const char* en);
 static void tvterm_esc_start(TVterm* p, u_char ch);
 static void tvterm_esc_bracket(TVterm*, u_char);
-static void tvterm_esc_traditional_mulitbyte_fix(TVterm* p, u_char ch);
-static void tvterm_esc_desginate_font(TVterm* p, u_char ch);
+static void tvterm_esc_traditional_multibyte_fix(TVterm* p, u_char ch);
+static void tvterm_esc_designate_font(TVterm* p, u_char ch);
 static void tvterm_invoke_gx(TVterm* p, TFontSpec* fs, u_int n);
 static void tvterm_re_invoke_gx(TVterm* p, TFontSpec* fs);
 void tvterm_set_window_size(TVterm* p);
@@ -449,7 +449,7 @@ void tvterm_emulate(TVterm* p, const char *buff, int nchars)
 #define ESC_ISO_GnDx(n, x) \
 	{\
 		p->escSignature |= (x); p->escGn = (n);\
-		p->esc = tvterm_esc_desginate_font;\
+		p->esc = tvterm_esc_designate_font;\
 	}
 
 #define Fe(x)	((x)-0x40)
@@ -462,7 +462,7 @@ static void tvterm_esc_start(TVterm* p, u_char ch)
 		p->esc = tvterm_esc_bracket;
 		break;
 	case ISO__MBS:
-		p->esc = tvterm_esc_traditional_mulitbyte_fix;
+		p->esc = tvterm_esc_traditional_multibyte_fix;
 		p->escSignature = TFONT_FT_DOUBLE;
 		break;
 	case ISO_GZD4:
@@ -477,12 +477,18 @@ static void tvterm_esc_start(TVterm* p, u_char ch)
 	case ISO_G1D6:
 		ESC_ISO_GnDx(1, TFONT_FT_96CHAR);
 		break;
-#if 0
 	case ISO_G2D4:
+		ESC_ISO_GnDx(2, TFONT_FT_94CHAR);
+		break;
 	case ISO_G2D6:
+		ESC_ISO_GnDx(2, TFONT_FT_96CHAR);
+		break;
 	case ISO_G3D4:
+		ESC_ISO_GnDx(3, TFONT_FT_94CHAR);
+		break;
 	case ISO_G3D6:
-#endif
+		ESC_ISO_GnDx(3, TFONT_FT_96CHAR);
+		break;
 	case Fe(ISO_NEL):		/* E */
 		p->pen.x = 0;
 		p->wrap = FALSE;
@@ -514,7 +520,7 @@ static void tvterm_esc_start(TVterm* p, u_char ch)
 		p->wrap = FALSE;
 		tvterm_set_default_invoke_and_designate(p);
 		/* fail into next case */
-	case TERM_CAH:
+/*	case TERM_CAH: - conflicts with ISO_G2D4, no terminfo */
 		p->pen.x = 0;
 		p->pen.y = 0;
 		p->wrap = FALSE;
@@ -527,6 +533,26 @@ static void tvterm_esc_start(TVterm* p, u_char ch)
 		tvterm_pop_pen_and_set_currnt_pen(p, TRUE);
 		p->wrap = FALSE;
 		break;
+	case ISO_LS2:
+		tvterm_invoke_gx(p, &(p->gl), 2); /* GL <= G2 */
+		p->tgl = p->gl;
+		break;
+	case ISO_LS3:
+		tvterm_invoke_gx(p, &(p->gl), 3); /* GL <= G3 */
+		p->tgl = p->gl;
+		break;
+	case ISO_LS3R:
+		tvterm_invoke_gx(p, &(p->gr), 3); /* GR <= G3 */
+		p->tgr = p->gr;
+		break;
+	case ISO_LS2R:
+		tvterm_invoke_gx(p, &(p->gr), 2); /* GR <= G2 */
+		p->tgr = p->gr;
+		break;
+	case ISO_LS1R:
+		tvterm_invoke_gx(p, &(p->gr), 1); /* GR <= G1 */
+		p->tgr = p->gr;
+		break;
 	}
 }
 
@@ -613,7 +639,6 @@ static void tvterm_set_region(TVterm* p,int ymin, int ymax)
 {
 	/* FIX ME ! : 1999/10/30 */
 	/* XXX: ESC[?1001r is used for mouse control by w3m. ukai 1999/10/27*/
-	/* XXX: ESC[?1001r is used for mouse control by w3m. oike 1999/11/05*/
 	if (ymin < 0 || ymin >= p->ycap || ymin > ymax || ymax > p->ycap) {
 	        /* ignore */
 		return;
@@ -839,7 +864,7 @@ static void tvterm_re_invoke_gx(TVterm* p, TFontSpec* fs)
 	fs->half = gFont[fs->idx].fhalf;
 }
 
-static void tvterm_esc_desginate_font(TVterm* p, u_char ch)
+static void tvterm_esc_designate_font(TVterm* p, u_char ch)
 {
 	int i;
 
@@ -855,10 +880,10 @@ static void tvterm_esc_desginate_font(TVterm* p, u_char ch)
 	p->esc = NULL;
 }
 
-static void tvterm_esc_traditional_mulitbyte_fix(TVterm* p, u_char ch)
+static void tvterm_esc_traditional_multibyte_fix(TVterm* p, u_char ch)
 {
 	if (ch == 0x40 || ch == 0x41 || ch == 0x42) {
-		tvterm_esc_desginate_font(p, ch);
+		tvterm_esc_designate_font(p, ch);
 	} else {
 		tvterm_esc_start(p, ch);
 	}
@@ -871,45 +896,45 @@ static void tvterm_esc_set_double_code(TVterm* p, u_char ch)
 	case ISO_GZD4:
 		p->escSignature = TFONT_FT_94CHAR | TFONT_FT_DOUBLE;
 		p->escGn = 0;
-		p->esc = tvterm_esc_desginate_font;
+		p->esc = tvterm_esc_designate_font;
 		break;
 	case ISO_G1D4:
 		p->escSignature = TFONT_FT_94CHAR | TFONT_FT_DOUBLE;
 		p->escGn = 1;
-		p->esc = tvterm_esc_desginate_font;
+		p->esc = tvterm_esc_designate_font;
 		break;
 	case ISO_G2D4:
 		p->escSignature = TFONT_FT_94CHAR | TFONT_FT_DOUBLE;
 		p->escGn = 2;
-		p->esc = tvterm_esc_desginate_font;
+		p->esc = tvterm_esc_designate_font;
 		break;
 	case ISO_G3D4:
 		p->escSignature = TFONT_FT_94CHAR | TFONT_FT_DOUBLE;
 		p->escGn = 3;
-		p->esc = tvterm_esc_desginate_font;
+		p->esc = tvterm_esc_designate_font;
 		break;
 	case MULE__GZD6:
 		p->escSignature = TFONT_FT_96CHAR | TFONT_FT_DOUBLE;
 		p->escGn = 0;
-		p->esc = tvterm_esc_desginate_font;
+		p->esc = tvterm_esc_designate_font;
 		break;
 	case ISO_G1D6:
 		p->escSignature = TFONT_FT_96CHAR | TFONT_FT_DOUBLE;
 		p->escGn = 1;
-		p->esc = tvterm_esc_desginate_font;
+		p->esc = tvterm_esc_designate_font;
 		break;
 	case ISO_G2D6:
 		p->escSignature = TFONT_FT_96CHAR | TFONT_FT_DOUBLE;
 		p->escGn = 2;
-		p->esc = tvterm_esc_desginate_font;
+		p->esc = tvterm_esc_designate_font;
 		break;
 	case ISO_G3D6:
 		p->escSignature = TFONT_FT_96CHAR | TFONT_FT_DOUBLE;
 		p->escGn = 3;
-		p->esc = tvterm_esc_desginate_font;
+		p->esc = tvterm_esc_designate_font;
 		break;
 	default:
-		tvterm_esc_desginate_font(p, ch);
+		tvterm_esc_designate_font(p, ch);
 		p->esc = NULL;
 		break;
 	}
